pub enum SlugSignature {
ShulginSigning(ShulginSignature),
EsphandSigning(EsphandSignature),
AbsolveSigning(AbsolveSignature),
ED25519(ED25519Signature),
ED448(Ed448Signature),
ECDSA(ECDSASignature, ECDSASignatureRecoveryID),
BLS12_381(BLSSignature),
SchnorrOverRistretto(SchnorrSignature),
SPHINCS(SPHINCSSignature),
FALCON1024(Falcon1024Signature),
MLDSA3(MLDSA3Signature),
}Variants
ShulginSigning(ShulginSignature)
ShulginSigning: A hybrid signature scheme combining classical and post-quantum algorithms.
EsphandSigning(EsphandSignature)
EsphandSigning: A signature scheme based on the Esphand algorithm, designed for high security and efficiency.
AbsolveSigning(AbsolveSignature)
AbsolveSigning: A signature scheme that provides strong security guarantees while maintaining performance.
ED25519(ED25519Signature)
ED448(Ed448Signature)
ECDSA(ECDSASignature, ECDSASignatureRecoveryID)
BLS12_381(BLSSignature)
SchnorrOverRistretto(SchnorrSignature)
SPHINCS(SPHINCSSignature)
FALCON1024(Falcon1024Signature)
MLDSA3(MLDSA3Signature)
Implementations
Sourceimpl SlugSignature
impl SlugSignature
pub fn as_alg(&self) -> Algorithms